import { LiquidHTMLable, LiquidStringable, toLiquidHtml, toLiquidString } from "../../drop";
/**
 * A string wrapper that is safe to output as HTML, either because it
 * has already been escaped or is considered safe without escaping.
 */
export declare class Markup implements LiquidHTMLable, LiquidStringable {
    #private;
    /**
     * `Markup` constructor.
     * @param s - Escaped or safe markup text.
     */
    constructor(s: string);
    /**
     * A `Markup` factory function.
     *
     * @param s - Escaped or safe markup text.
     * @returns The input string inside a `Markup` wrapper.
     */
    static from(s: string | Markup): Markup;
    /**
     * A `Markup` factory function that will escape the input value if it is
     * not already `Markup`.
     *
     * @param value - Any value. If it's already `Markup`, it will be returned
     * unchanged. Otherwise it will be converted to a string and escaped.
     * @returns A string representation of the input value after HTML-escaping.
     */
    static escape(value: unknown): Markup;
    get [Symbol.toStringTag](): string;
    [Symbol.toPrimitive](hint: string): string | null;
    [toLiquidHtml](): string;
    [toLiquidString](): string;
    toString(): string;
}
