import { FilterContext } from "../../filter";
import { Markup } from "../drops/markup";
import { NumberT } from "../../number";
/**
 * Concatenate items in an array-like object into a single string, separated by
 * a separator string.
 *
 * If the input value is not array-like, it will be coerced to one. If input
 * array items are not strings, they will be converted to strings before joining.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value. If it's not iterable, a new array will be used with
 * the value as its first and only item.
 * @param separator - A string to be used to separate input items in the output
 * string. Defaults to a single space.
 * @returns Items in the input array, concatenated together and separated by
 * the given separator.
 */
export declare function join(this: FilterContext, left: unknown, separator?: unknown): string | Markup;
/**
 * Return the first item of the input sequence. The input could be array-like
 * or a mapping, but not a string.
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value.
 * @returns The first item in the input iterable, or `null` if the input value
 * is not iterable, or `undefined` if the iterable is empty.
 */
export declare function first(this: FilterContext, left: unknown): unknown;
/**
 * Return the last item of the input sequence. The input could be array-like,
 * but not a string.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value.
 * @returns The last item in the input iterable, or `null` if the input value
 * is not iterable.
 */
export declare function last(this: FilterContext, left: unknown): unknown;
/**
 * Remove `null` and `undefined` values from an array-like object. If given, the
 * argument should be the name of a property that exists on each object in the
 * array-like sequence.
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value.
 * @param prop - The name of a property to check for `null` or `undefined`
 * values. Each object in the input iterable should have this property.
 * @returns - A new array with `null` and `undefined` values removed.
 */
export declare function compact(this: FilterContext, left: unknown, prop?: unknown): unknown[];
/**
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left -
 * @param arg -
 * @returns
 */
export declare function concat(this: FilterContext, left: unknown, arg: unknown): unknown[];
/**
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left -
 * @param key -
 * @returns
 */
export declare function map(this: FilterContext, left: unknown, key: unknown): unknown[];
/**
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left -
 * @returns
 */
export declare function reverse(this: FilterContext, left: unknown): unknown[];
/**
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left -
 * @param key -
 * @returns
 */
export declare function sort(this: FilterContext, left: unknown, key?: unknown): unknown[];
/**
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left -
 * @param key -
 * @returns
 */
export declare function sortNatural(this: FilterContext, left: unknown, key?: unknown): unknown[];
/**
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left -
 * @param prop -
 * @returns
 */
export declare function uniq(this: FilterContext, left: unknown, prop?: unknown): unknown[];
/**
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left -
 * @param prop -
 * @param value -
 * @returns
 */
export declare function where(this: FilterContext, left: unknown, prop: unknown, value?: unknown): unknown[];
/**
 * Return the sum of all numeric items in _left_.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left -
 * @param prop -
 * @returns
 */
export declare function sum(this: FilterContext, left: unknown, prop?: unknown): NumberT;
