import { FilterContext } from "../../filter";
import { Markup } from "../drops/markup";
/**
 * Return the length of an array or string. If the input is an object or map,
 * returns the number of keys.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value.
 * @returns The size of an object or `0` if a size can not be determined.
 */
export declare function size(this: FilterContext, left: unknown): number;
/**
 * Return a default value if the input is nil, false or empty.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value.
 * @param _default - Optional default value. Defaults to an empty string.
 * @returns The default value if the input is nil, false or empty.
 */
export declare function default_(this: FilterContext, left: unknown, _default?: unknown): unknown;
/**
 * Format a date according to the given format string. If the input is not a
 * date it will be converted to a string and parsed using one of the common
 * date representation standards.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - The date to be formatted.
 * @param format - A format string.
 * @returns A string representation of the input date according to the given
 * format string.
 */
export declare function date(this: FilterContext, left: unknown, format: unknown): string;
/**
 * Return a substring or subsequence of the input value.
 *
 * @param this - An object containing a reference to the active render context
 * and any keyword/named arguments.
 * @param left - Any value. If its not an array or string, it will be
 * converted to a string.
 * @param offset - Start of the subsequence in number of items or characters.
 * @param length - The maximum number of items or characters in the resulting
 * sequence.
 * @returns A substring for subsequence.
 */
export declare function slice(this: FilterContext, left: unknown, offset: unknown, length?: unknown): string | unknown[] | Markup;
