import { BlockNode, Node, ChildNode } from "../../ast";
import { RenderContext } from "../../context";
import { Environment } from "../../environment";
import { LoopExpression } from "../../expression";
import { RenderStream } from "../../io/output_stream";
import { Tag } from "../../tag";
import { Token, TokenStream } from "../../token";
export declare class BreakTag implements Tag {
    readonly name: string;
    readonly block = false;
    parse(stream: TokenStream): BreakNode;
}
export declare class ContinueTag implements Tag {
    readonly name: string;
    readonly block = false;
    parse(stream: TokenStream): ContinueNode;
}
export declare class ForTag implements Tag {
    protected static ENDFORBLOCK: Set<string>;
    protected static ENDFORELSEBLOCK: Set<string>;
    readonly name: string;
    readonly block = true;
    readonly end: string;
    protected nodeClass: typeof ForNode;
    parse(stream: TokenStream, environment: Environment): Node;
}
export declare class BreakNode implements Node {
    readonly token: Token;
    constructor(token: Token);
    toString(): string;
    render(): Promise<void>;
    renderSync(): void;
    children(): ChildNode[];
}
export declare class ContinueNode implements Node {
    readonly token: Token;
    constructor(token: Token);
    toString(): string;
    render(): Promise<void>;
    renderSync(): void;
    children(): ChildNode[];
}
export declare class ForNode implements Node {
    readonly token: Token;
    readonly expression: LoopExpression;
    readonly block: BlockNode;
    readonly default_?: BlockNode | undefined;
    forceOutput: boolean;
    constructor(token: Token, expression: LoopExpression, block: BlockNode, default_?: BlockNode | undefined);
    render(context: RenderContext, out: RenderStream): Promise<void>;
    renderSync(context: RenderContext, out: RenderStream): void;
    children(): ChildNode[];
}
