import { AssignTag, EchoTag, OutputStatement } from "../../builtin/tags";
import { Node } from "../../ast";
import { TokenStream } from "../../token";
import { Expression } from "../../expression";
/**
 * A drop-in replacement for the standard output statement that supports
 * inline `if` expressions.
 */
export declare class ConditionalOutputStatement extends OutputStatement {
    parse(stream: TokenStream): Node;
}
/**
 * A drop-in replacement for the standard assign tag that supports
 * inline `if` expressions.
 */
export declare class ConditionalAssignTag extends AssignTag {
    protected parseExpression(value: string, startIndex: number): Expression;
}
/**
 * A drop-in replacement for the standard echo tag that supports
 * inline `if` expressions.
 */
export declare class ConditionalEchoTag extends EchoTag {
    protected parseExpression(value: string, startIndex: number): Expression;
}
/**
 * A drop-in replacement for the standard output statement that supports
 * inline `if` expressions with a logical `not` operator and grouping
 * terms with parentheses.
 */
export declare class ConditionalOutputStatementWithParens extends OutputStatement {
    parse(stream: TokenStream): Node;
}
/**
 * A drop-in replacement for the standard assign tag that supports
 * inline `if` expressions with a logical `not` operator and grouping
 * terms with parentheses.
 */
export declare class ConditionalAssignTagWithParens extends AssignTag {
    protected parseExpression(value: string, startIndex: number): Expression;
}
/**
 * A drop-in replacement for the standard echo tag that supports
 * inline `if` expressions with a logical `not` operator and grouping
 * terms with parentheses.
 */
export declare class ConditionalEchoTagWithParens extends EchoTag {
    protected parseExpression(value: string, startIndex: number): Expression;
}
