/**
 * An object to which a {@link Tag} can write its rendered content to.
 */
export interface RenderStream {
    /**
     * Write rendered content to the output stream.
     * @param value - Template output text.
     */
    write(value: string): void;
    size?: number;
}
/**
 * A {@link RenderStream} implementation that buffers rendered content
 * in memory.
 */
export declare class BufferedRenderStream implements RenderStream {
    private buffer;
    constructor(buffer?: string[]);
    write(value: string): void;
    toString(): string;
}
/**
 * A {@link RenderStream} implementation that buffers rendered content in
 * memory and throws an OutputStreamLimitError if bytes written exceed its
 * limit.
 */
export declare class LimitedRenderStream implements RenderStream {
    private limit;
    private buffer;
    size: number;
    constructor(limit: number, buffer?: string[]);
    write(value: string): void;
    toString(): string;
}
